## What's Changed

hotfix of 4.17.0

- 修复：MCP 服务器的 Tools 没有被正确添加到上下文中。
- 修复：Electron 桌面应用部署时，系统自带插件未被正确加载的问题。
- fix: Tools from MCP server were not properly added to context.
- fix: built-in plugins were not properly loaded in Electron desktop application deployment.
